import{d as g,ez as v,eA as b,r as k,b as r,c as s,w as a,u as e,f as l,ew as i}from"./outputWidgets.541a6a3f.js";import{S as h,L as w}from"./SmartConsole.e1c7bfc3.js";import{a as B}from"./asyncComputed.6496ca6b.js";import{H as C}from"./hooks.c3613214.js";import{_ as H}from"./SaveButton.vue_vue_type_script_setup_true_lang.af310abc.js";import{_ as I}from"./DocsButton.vue_vue_type_script_setup_true_lang.3e45b890.js";import{B as S}from"./BaseLayout.5761ab4f.js";import{_ as T,a as x}from"./HookSettings.vue_vue_type_script_setup_true_lang.f8aa130b.js";import{c as A}from"./index.7fb7f882.js";import{A as _,T as D}from"./TabPane.40396dd5.js";import"./forms.4ff36d50.js";import"./activeRecord.867c40fa.js";import"./pubsub.8482a29f.js";import"./dashes.438c0418.js";import"./index.1b1480b6.js";import"./jobs.8963c228.js";import"./workspaces.d27d9f39.js";import"./icons.fbbc5318.js";import"./Title.3011141f.js";import"./index.3cff0676.js";import"./uuid.25354c68.js";import"./ant-design.e75c36c7.js";import"./index.dda022dd.js";import"./index.33fb7a48.js";import"./index.1797b918.js";import"./index.f20ad580.js";import"./Form.2a9acb85.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[m]="51ec9975-4dae-4259-a372-24e45d650fd8",n._sentryDebugIdIdentifier="sentry-dbid-51ec9975-4dae-4259-a372-24e45d650fd8")}catch{}})();const ne=g({__name:"HookEditor",setup(n){const m=v(),p=b(),c=k(null),o=k("test");function y(){m.push({name:"hooks"})}const{result:t}=B(()=>C.get(p.params.hookPath)),f=w.create();return(R,d)=>(r(),s(S,null,{navbar:a(()=>[e(t)?(r(),s(e(A),{key:0,title:e(t).title,onBack:y},{footer:a(()=>[l(e(D),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=u=>o.value=u)},{default:a(()=>[l(e(_),{key:"test",tab:"Test"}),l(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:a(()=>[l(I,{path:"hooks"}),o.value==="settings"?(r(),s(H,{key:0,model:e(t)},null,8,["model"])):i("",!0)]),_:1},8,["title"])):i("",!0)]),content:a(()=>[e(t)&&o.value==="test"?(r(),s(T,{key:0,ref_key:"tester",ref:c,hook:e(t),"log-service":e(f)},null,8,["hook","log-service"])):i("",!0),e(t)&&o.value==="settings"?(r(),s(x,{key:1,hook:e(t)},null,8,["hook"])):i("",!0)]),footer:a(()=>{var u;return[e(t)&&o.value==="test"?(r(),s(h,{key:0,runtime:"forms","log-service":e(f),onRestart:(u=c.value)==null?void 0:u.runHook},null,8,["log-service","onRestart"])):i("",!0)]}),_:1}))}});export{ne as default};
//# sourceMappingURL=HookEditor.6d274d94.js.map
