import{x as a,a as o,b as i,c,g as p,h as _,_ as d,i as u,T as f,j as l,P as h,C as m,M as y,s as b,k as s,l as g,m as v,n as w,p as I}from"./outputWidgets.541a6a3f.js";import{u as k}from"./index.669ed6e9.js";import"./pubsub.8482a29f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="e48acb04-49f7-4f65-8833-aab7f1cfe592",e._sentryDebugIdIdentifier="sentry-dbid-e48acb04-49f7-4f65-8833-aab7f1cfe592")}catch{}})();const x={};function A(e,t){const r=o("router-view");return i(),c(r,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const D=a(x,[["render",A]]),n=p({history:_("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>d(()=>import("./Player.55d1b371.js"),["assets/Player.55d1b371.js","assets/index.1b1480b6.js","assets/outputWidgets.541a6a3f.js","assets/outputWidgets.8ce475af.css","assets/uuid.25354c68.js","assets/broker.7dc50939.js","assets/index.669ed6e9.js","assets/pubsub.8482a29f.js","assets/executeJs.16417bf7.js","assets/icons.fbbc5318.js","assets/CircularLoading.46b3501d.js","assets/CircularLoading.f81b57b4.css","assets/PlayerNavbar.f92ecc26.js","assets/PlayerNavbar.76a7eb2f.css","assets/Steps.554db205.js","assets/Steps.998aa76d.css","assets/Modal.e29b464d.js","assets/Modal.5aaf8eba.css","assets/executeJs.9c4b02ee.css","assets/WidgetsFrame.2d6f15b2.js","assets/WidgetsFrame.0816a5f5.css","assets/ActionButton.vue_vue_type_script_setup_true_lang.a70d3ffa.js","assets/broker.ac4594bd.css","assets/DashPlayer.1021fe23.js","assets/geometryUtils.2e28a652.js","assets/DashPlayer.4868beea.css","assets/asyncComputed.6496ca6b.js","assets/Player.77337a17.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class P{static init(){setInterval(()=>fetch("/_healthcheck"),20*1e3)}}(async()=>{await k();const e=u({render:()=>g(D)});f.init(),l(e,n),P.init(),e.use(n),e.use(h),e.mount("#app"),e.component("VSelect",m),e.component("Markdown",y),e.component("Message",b),s(e,v),s(e,w),s(e,I)})();
//# sourceMappingURL=player.a5af1402.js.map
