import{R as d}from"./Title.3011141f.js";import{F as n}from"./outputWidgets.541a6a3f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="b02afc91-db0f-4f9e-85b3-d8321ba719c2",e._sentryDebugIdIdentifier="sentry-dbid-b02afc91-db0f-4f9e-85b3-d8321ba719c2")}catch{}})();const s=n(d);export{s as A};
//# sourceMappingURL=index.3cff0676.js.map
