import{d as u,eA as b,J as c,a as g,b as f,c as v,w as i,f as s}from"./outputWidgets.541a6a3f.js";import{B as _}from"./BaseLayout.5761ab4f.js";import{a as h}from"./asyncComputed.6496ca6b.js";import{P as y}from"./project.99ccb1d4.js";import"./console.7080c244.js";import{O as z}from"./organization.8c5c9dd0.js";import"./index.56c0102f.js";import{_ as j}from"./Navbar.vue_vue_type_script_setup_true_lang.f0e39c34.js";import{S as I}from"./Sidebar.d0176ff3.js";import{I as w,J as k,K as B,L as P,M as $,N as C,O as M,F as x,G as D,H as L}from"./icons.fbbc5318.js";import"./gateway.647cec74.js";import"./activeRecord.867c40fa.js";import"./pubsub.8482a29f.js";import"./index.1b1480b6.js";import"./Form.2a9acb85.js";import"./Title.3011141f.js";import"./index.7fb7f882.js";import"./index.33fb7a48.js";import"./index.5d5870f2.js";import"./dayjs.03d6e1d3.js";import"./index.f20ad580.js";import"./index.d89692b2.js";import"./TabPane.40396dd5.js";import"./index.ef35da09.js";import"./index.c3edc651.js";import"./index.dda022dd.js";import"./index.1797b918.js";import"./index.7f86f9a3.js";import"./index.68ffc7e6.js";import"./index.3cff0676.js";import"./index.07910c0e.js";import"./logo.084e5d7c.js";import"./Tooltip.b122611e.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="fabafb1d-d509-4346-8f63-8b6ef156ad09",t._sentryDebugIdIdentifier="sentry-dbid-fabafb1d-d509-4346-8f63-8b6ef156ad09")}catch{}})();const ua=u({__name:"Project",setup(t){const p=b().params.projectId,{result:a}=h(()=>y.get(p).then(async o=>{const e=await z.get(o.organizationId);return{project:o,organization:e}})),l=c(()=>{var o,e,n,m;return((o=a.value)==null?void 0:o.organization)&&a.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(e=a.value)==null?void 0:e.organization)==null?void 0:n.name,path:`/organizations/${(m=a.value)==null?void 0:m.organization.id}`},{label:a.value.project.name,path:`/projects/${a.value.project.id}`}]:void 0}),d=c(()=>{var o;return(o=a.value)!=null&&o.project?[{name:"Project",items:[{name:"Builds",path:"builds",icon:w},{name:"Connectors",path:"connectors",icon:k},{name:"Tables",path:"tables",icon:B},{name:"API Keys",path:"api-keys",icon:P},{name:"Env Vars",path:"env-vars",icon:$},{name:"Logs",icon:C,path:"logs",beta:!0},{name:"Settings",icon:M,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:x,path:`/organizations/${a.value.project.organizationId}/projects`},{name:"Members",icon:D,path:`/organizations/${a.value.project.organizationId}/members`},{name:"Billing",icon:L,path:`/organizations/${a.value.project.organizationId}/billing`,unavailable:!0}]}]:[]});return(o,e)=>{const n=g("router-view");return f(),v(_,null,{content:i(()=>[s(n)]),navbar:i(()=>[s(j,{class:"nav",breadcrumb:l.value},null,8,["breadcrumb"])]),sidebar:i(()=>[s(I,{class:"sidebar",sections:d.value},null,8,["sections"])]),_:1})}}});export{ua as default};
//# sourceMappingURL=Project.31d174fa.js.map
