import{d as g,ez as v,eA as k,r as d,b as r,c as s,w as a,u as e,f as l,ew as i}from"./outputWidgets.541a6a3f.js";import{S as w,L as j}from"./SmartConsole.e1c7bfc3.js";import{a as I}from"./asyncComputed.6496ca6b.js";import{J as B}from"./jobs.8963c228.js";import{_ as C}from"./SaveButton.vue_vue_type_script_setup_true_lang.af310abc.js";import{_ as S}from"./DocsButton.vue_vue_type_script_setup_true_lang.3e45b890.js";import{B as T}from"./BaseLayout.5761ab4f.js";import{_ as x,a as A}from"./JobSettings.vue_vue_type_script_setup_true_lang.ca02b8dd.js";import{c as D}from"./index.7fb7f882.js";import{A as _,T as R}from"./TabPane.40396dd5.js";import"./forms.4ff36d50.js";import"./activeRecord.867c40fa.js";import"./pubsub.8482a29f.js";import"./dashes.438c0418.js";import"./index.1b1480b6.js";import"./hooks.c3613214.js";import"./workspaces.d27d9f39.js";import"./icons.fbbc5318.js";import"./Title.3011141f.js";import"./index.3cff0676.js";import"./uuid.25354c68.js";import"./ant-design.e75c36c7.js";import"./dayjs.03d6e1d3.js";import"./index.f20ad580.js";import"./Form.2a9acb85.js";import"./index.33fb7a48.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[m]="6ef2471b-1380-4435-bd9b-083251b0fab7",n._sentryDebugIdIdentifier="sentry-dbid-6ef2471b-1380-4435-bd9b-083251b0fab7")}catch{}})();const ae=g({__name:"JobEditor",setup(n){const m=v(),f=k(),p=d(null),o=d("test");function y(){m.push({name:"jobs"})}const{result:t}=I(()=>B.get(f.params.jobId)),c=j.create();return($,b)=>(r(),s(T,null,{navbar:a(()=>[e(t)?(r(),s(e(D),{key:0,title:e(t).title,onBack:y},{footer:a(()=>[l(e(R),{"active-key":o.value,"onUpdate:activeKey":b[0]||(b[0]=u=>o.value=u)},{default:a(()=>[l(e(_),{key:"test",tab:"Test"}),l(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:a(()=>[l(S),o.value==="settings"?(r(),s(C,{key:0,model:e(t)},null,8,["model"])):i("",!0)]),_:1},8,["title"])):i("",!0)]),content:a(()=>[e(t)&&o.value==="test"?(r(),s(x,{key:0,ref_key:"tester",ref:p,job:e(t),"log-service":e(c)},null,8,["job","log-service"])):i("",!0),e(t)&&o.value==="settings"?(r(),s(A,{key:1,job:e(t)},null,8,["job"])):i("",!0)]),footer:a(()=>{var u;return[e(t)&&o.value==="test"?(r(),s(w,{key:0,runtime:"forms","log-service":e(c),onRestart:(u=p.value)==null?void 0:u.test},null,8,["log-service","onRestart"])):i("",!0)]}),_:1}))}});export{ae as default};
//# sourceMappingURL=JobEditor.43dab784.js.map
