import{C as n}from"./Title.3011141f.js";import{F as d}from"./outputWidgets.541a6a3f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="87c1ce86-c4b2-4de3-a138-844155ea8462",e._sentryDebugIdIdentifier="sentry-dbid-87c1ce86-c4b2-4de3-a138-844155ea8462")}catch{}})();const a=d(n);export{a as A};
//# sourceMappingURL=index.c3edc651.js.map
