import{cN as n}from"./outputWidgets.541a6a3f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="7a598147-5f47-44e2-8b5e-1f39952970a5",e._sentryDebugIdIdentifier="sentry-dbid-7a598147-5f47-44e2-8b5e-1f39952970a5")}catch{}})();const f=(e,r)=>{n.error({message:e,description:r})};export{f as p};
//# sourceMappingURL=popupNotifcation.b07ed784.js.map
