import{d as o,b as a,c as r,w as d,b2 as c,u as i,cd as f}from"./outputWidgets.541a6a3f.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="7f8aba8d-7b68-492b-bcef-ec735241dfd8",t._sentryDebugIdIdentifier="sentry-dbid-7f8aba8d-7b68-492b-bcef-ec735241dfd8")}catch{}})();class p{async get(){return(await fetch("/_editor/api/login")).json()}async create(e){return(await fetch("/_editor/api/login",{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({token:e})})).json()}async delete(){await fetch("/_editor/api/login",{method:"DELETE"})}}const l=new p,u=o({__name:"DocsButton",props:{path:{}},setup(t){return(e,n)=>{var s;return a(),r(i(f),{class:"docs-button",href:`https://docs.abstra.io/${(s=e.path)!=null?s:""}`,target:"_blank"},{default:d(()=>[c(" Docs ")]),_:1},8,["href"])}}});export{u as _,l};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.3e45b890.js.map
