import{d as r,r as l,o as d,eP as f,b as c,et as u,eC as b,eN as p}from"./outputWidgets.541a6a3f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="30e3346b-4321-4477-847f-49f26abb7b54",e._sentryDebugIdIdentifier="sentry-dbid-30e3346b-4321-4477-847f-49f26abb7b54")}catch{}})();const m=r({__name:"ActionButton",props:{action:{},displayName:{}},emits:["click"],setup(e,{emit:n}){const o=e,s=l(null);return d(()=>{s.value&&o.action.setElement(s.value),f.addAction(o.action)}),(a,t)=>(c(),u("button",{ref_key:"element",ref:s,class:"next-button",onClick:t[0]||(t[0]=i=>n("click")),onKeydown:t[1]||(t[1]=p(i=>n("click"),["enter"]))},b(a.displayName),545))}});export{m as _};
//# sourceMappingURL=ActionButton.vue_vue_type_script_setup_true_lang.a70d3ffa.js.map
